@@ -5,12 +5,17 @@ use warnings;
 use base 'Tie::Array';
 use Storable ();
 
+# create new tied array
+sub TIEARRAY {
+    my ($class, $share) = @_;
+    my $self = bless { share => $share }, $class;
+    $self;
+}
+
+
 sub _get {
     my $self = shift;
-
-    return $self->{share}->lock_cb(sub {
-        $self->{share}->get('array');
-    });
+    return $self->{share}->get('array');
 }
 sub FETCH {
     my ($self, $index) = @_;
@@ -22,20 +27,14 @@ sub FETCHSIZE {
     scalar @$ary;
 }
 
-sub TIEARRAY {
-    my ($class, $share) = @_;
-    my $self = bless { share => $share }, $class;
-    $self;
-}
-
 sub STORE {
     my ($self, $index, $val) = @_;
 
     $self->{share}->lock_cb(sub {
         my $share = $self->{share};
-        my $cur = $share->get('array');
+        my $cur = $share->get_nolock('array');
         $cur->[$index] = $val;
-        $share->set(array => $cur);
+        $share->set_nolock(array => $cur);
     });
 }
 
